# -*-coding:utf-8-*-

def tagging(sent):
    from konlpy.tag import Kkma
    kkma = Kkma()
    return [pos+'/'+tag for pos, tag in kkma.pos(sent)]

def tagging_no_tag(sent):
    from konlpy.tag import Kkma
    kkma = Kkma()
    return [pos for pos, tag in kkma.pos(sent)]

def get_nouns(sent):
    from konlpy.tag import Kkma
    kkma = Kkma()
    return kkma.nouns(sent)


# -*- coding: utf-8 -*-
'''/**
     * created by M. Im 2017-11-10
     */'''

def ngram(L,ngramN):
    L2,size=[],len(L)
    for i in range(size):
        for n in ngramN:
            if i+n<=size: L2.append('_'.join(L[i:i+n]))
        # end for
    # end for

    return L2

def Space_skip_ngram(L,ngramN):
    Ls = L.split()
    Space_skip_ngrams = []
    for l in Ls:

        if len(l)<ngramN[0]:
            pass
        else:

            Space_skip_ngrams+=ngram(l,ngramN)

    return Space_skip_ngrams


# -*- coding:utf-8 -*-
# writer: Mia at 16. 9. 9, 
# last revision: 오후 11:22

from time import strftime,localtime

def print_time():
    print (strftime("[%H:%M:%S]", localtime()),)

def print_time_msg(msg):
    print (strftime("[%H:%M:%S]", localtime()), msg)


# -*- coding: utf-8 -*-
'''/**
     * created by M. Im 2017-08-03
     */'''

def get_paths(directory):
    import os
    try:
        os.path.exists(directory)
        return [os.path.join(directory,f) for f in os.listdir(directory)]
    except:
        print('Path doesn\'t exists or it is not a directory! ')


#-*- coding:utf-8 -*-
import os
from setuptools import setup

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "txt_util",
    version = "0.0.1",
    author = "Meeyeong Im",
    author_email = "meeyeong1211@gmail.com",
    description = ("file_op;abs_path;cosine_sim;get_ngram;load_json;pos_tagging;time_printer."),
    license = "BSD",
    keywords = "some txt parsing util",
    
    packages=['txt_util'],
    long_description=read('README'),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: BSD License",
    ],
)




# -*- coding:utf-8 -*-
# writer: Mia at 16. 9. 9, 
# last revision: 오후 11:24

def read_file(f):
    with open(f,'r') as rf:
        return rf.read()


def read_file_utf8(f):
    from codecs import open as copen
    with copen(f, 'r','utf-8') as rf:
        return rf.read()

def read_file_kr(f):
    from codecs import open as copen
    with copen(f, 'r','euc-kr') as rf:
        return rf.read()

def read_pf(f):
    import pickle
    with open(f,'rb') as pf:
        return pickle.load(pf)


def write_file(f,String_obj):
    with open(f,'w') as wf:
        wf.write(String_obj)


def write_file_utf8(f,obj):
    from codecs import open as copen
    with copen(f,'w','utf-8') as wf:
        wf.write(obj)

def write_pf(f,obj):
    import pickle
    with open(f,'wb') as pf:
        pickle.dump(obj,pf)